==> onepyece-1.3.1-py3-none-any.whl: onepyece/__init__.py <==
"""
One Piece API wrapper (french data)
"""
from .functions import *
from .interface import API

__all__ = [
    "API",
    "episode_by_id",
    "episode_by_title",
    "episode_by_saga_id",
    "episode_by_arc_id",
    "episode_by_arc_title",
    "episode_by_saga_title",
    "count_episodes",
    "movie_by_id",
    "movie_by_title",
    "count_movies",
    "tome_by_id",
    "tome_by_title",
    "count_tomes",
    "chapter_by_id",
    "chapter_by_title",
    "count_chapters",
    "arc_by_id",
    "arc_by_title",
    "arc_by_saga_id",
    "count_arcs",
    "saga_by_id",
    "saga_by_title",
    "count_sagas",
    "haki_by_id",
    "haki_by_name",
    "haki_by_roman_name",
    "haki_by_characters_id",
    "count_hakis",
    "character_by_id",
    "character_by_name",
    "character_by_job",
    "character_by_bounty",
    "character_by_status",
    "character_by_size",
    "count_characters",
    "dial_by_id",
    "dial_by_name",
    "dial_by_type",
    "count_dials",
    "luffy_gear_by_id",
    "luffy_gear_by_title",
    "count_luffy_gears",
    "luffy_technique_by_id",
    "luffy_technique_by_name",
    "luffy_technique_by_translation",
    "count_luffy_techniques",
    "locate_by_id",
    "locate_by_name",
    "locate_by_sea",
    "locate_by_affiliation",
    "count_locates",
    "fruit_by_id",
    "fruit_by_name",
    "fruit_by_type",
    "count_fruits",
    "sword_by_id",
    "sword_by_name",
    "count_swords",
    "boat_by_id",
    "boat_by_name",
    "boat_by_type",
    "boat_by_crew_id",
    "boat_by_captain_id",
    "count_boats",
    "crew_by_id",
    "crew_by_name",
    "crew_by_status",
    "count_crews",
]

==> onepyece-2.0.1-py3-none-any.whl: onepyece/__init__.py <==
"""
One Piece API wrapper (french data)
"""
from .functions import *
from .interface import API

__all__ = [
    "API",
    "episode_by_id",
    "episode_by_title",
    "episode_by_saga_id",
    "episode_by_arc_id",
    "episode_by_arc_title",
    "episode_by_saga_title",
    "count_episodes",
    "movie_by_id",
    "movie_by_title",
    "count_movies",
    "tome_by_id",
    "tome_by_title",
    "count_tomes",
    "chapter_by_id",
    "chapter_by_title",
    "count_chapters",
    "arc_by_id",
    "arc_by_title",
    "arc_by_saga_id",
    "count_arcs",
    "saga_by_id",
    "saga_by_title",
    "count_sagas",
    "haki_by_id",
    "haki_by_name",
    "haki_by_roman_name",
    "haki_by_character_id",
    "count_hakis",
    "character_by_id",
    "character_by_name",
    "character_by_job",
    "character_by_bounty",
    "character_by_status",
    "character_by_size",
    "count_characters",
    "dial_by_id",
    "dial_by_name",
    "dial_by_type",
    "count_dials",
    "luffy_gear_by_id",
    "luffy_gear_by_title",
    "count_luffy_gears",
    "luffy_technique_by_id",
    "luffy_technique_by_name",
    "luffy_technique_by_translation",
    "count_luffy_techniques",
    "locate_by_id",
    "locate_by_name",
    "locate_by_sea",
    "locate_by_affiliation",
    "count_locates",
    "fruit_by_id",
    "fruit_by_name",
    "fruit_by_type",
    "count_fruits",
    "sword_by_id",
    "sword_by_name",
    "sword_by_type",
    "sword_by_state",
    "count_swords",
    "boat_by_id",
    "boat_by_name",
    "boat_by_type",
    "boat_by_crew_id",
    "boat_by_captain_id",
    "count_boats",
    "crew_by_id",
    "crew_by_name",
    "crew_by_status",
    "count_crews",
]
